# coding: utf-8

# flake8: noqa

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "2.3.40"

# Define package exports
__all__ = [
    "BackupAPIApi",
    "CodeSnippetAPIApi",
    "EntityAPIApi",
    "ExportImportConfigurationAPIApi",
    "HealthCheckAPIApi",
    "InterceptionConfigurationAPIApi",
    "LocaleAPIApi",
    "PluginV2APIApi",
    "SystemAPIApi",
    "TemplateAPIApi",
    "TranslationAPIApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AddLocaleRequest",
    "AttributeAnalyticsDbConfiguration",
    "AttributeIdentifier",
    "BackupRequest",
    "BackupResponse",
    "BaseLocale",
    "BaseSelectableValue",
    "BasicAttributeData",
    "BasicTemplateData",
    "BuiltInAttribute",
    "Category",
    "CodeSnippetResponse",
    "CreateBuiltInAttribute",
    "CreateCodeSnippetRequest",
    "CreateCustomAttribute",
    "CreatePluginRequest",
    "CreateTemplateAttribute",
    "CreateTemplateRequest",
    "Credentials",
    "CustomAttribute",
    "DockerRepositoryTempCredentialsResponse",
    "EntityNotifiableAction",
    "EntityType",
    "EntityTypeBuiltInAction",
    "EntityTypeBuiltInAttribute",
    "EntityTypeTemplateAttribute",
    "ErrorResponse",
    "ExportExecutionResponse",
    "ExportsMetadataResponse",
    "FileConfigurationMetadataResponse",
    "FilterV2",
    "GetCategoryResponse",
    "GetEntityTypesResponse",
    "GetNotifiableActions",
    "GetTemplateResponse",
    "ImportExecutionResponse",
    "InterceptionConfigurationResponse",
    "InterceptionSubscriptionDto",
    "InvalidTranslation",
    "JsonNullableListCorsAllowedHttpMethodEnum",
    "JsonNullableListInterceptionSubscriptionDto",
    "JsonNullableListNotificationSubscriptionDto",
    "JsonNullableListString",
    "JsonNullableSetBaseLocale",
    "LinkConfiguration",
    "LocaleTranslationsCoverage",
    "LocaleTranslationsOverview",
    "LocalesResponse",
    "Metadata",
    "NotificationSubscriptionDto",
    "NumericMetaData",
    "Order",
    "OrganizationSelection",
    "OrganizationSelectionConfiguration",
    "PageMetadata",
    "ParentTemplateResponse",
    "PartialPluginCorsConfig",
    "PartialUpdatePluginRequest",
    "PartialUpdateSubscriptionDto",
    "PluginCorsConfig",
    "PluginResponse",
    "PrimaryAdministrator",
    "ReferenceConfiguration",
    "ResetSystemRequest",
    "RestoreResponse",
    "SearchRequestV2",
    "SearchResponseBackupResponse",
    "SearchResponseCodeSnippetResponse",
    "SearchResponseEntityType",
    "SearchResponseGetTemplateResponse",
    "SearchResponseInterceptionConfigurationResponse",
    "SearchResponseLocaleTranslationsOverview",
    "SearchResponsePluginResponse",
    "SearchResponseRestoreResponse",
    "SearchResponseTemplateMinimizedResponse",
    "SelectableValue",
    "SelectedOrganization",
    "StartExportConfigurationRequest",
    "StartImportConfigurationRequest",
    "SubscriptionDto",
    "SystemPropertiesResponse",
    "TemplateAnalyticsDbConfiguration",
    "TemplateAttribute",
    "TemplateMinimizedResponse",
    "TemplateOverviewResponse",
    "TemplateStatistics",
    "UpdateBuiltInAttribute",
    "UpdateCustomAttribute",
    "UpdateLocaleTranslationsResponse",
    "UpdateLocalesRequest",
    "UpdateTemplateAttribute",
    "UpdateTemplateRequest",
    "ValidateLocaleTranslationsResponse",
    "ValidationDefinitionMetadataObject",
    "ValidationDefinitionObject",
    "VersionResponse",
]

if __import__("typing").TYPE_CHECKING:
    # import apis into sdk package
    from biotmed_settings_sdk.api.backup_api_api import BackupAPIApi as BackupAPIApi
    from biotmed_settings_sdk.api.code_snippet_api_api import CodeSnippetAPIApi as CodeSnippetAPIApi
    from biotmed_settings_sdk.api.entity_api_api import EntityAPIApi as EntityAPIApi
    from biotmed_settings_sdk.api.export_import_configuration_api_api import ExportImportConfigurationAPIApi as ExportImportConfigurationAPIApi
    from biotmed_settings_sdk.api.health_check_api_api import HealthCheckAPIApi as HealthCheckAPIApi
    from biotmed_settings_sdk.api.interception_configuration_api_api import InterceptionConfigurationAPIApi as InterceptionConfigurationAPIApi
    from biotmed_settings_sdk.api.locale_api_api import LocaleAPIApi as LocaleAPIApi
    from biotmed_settings_sdk.api.plugin_v2_api_api import PluginV2APIApi as PluginV2APIApi
    from biotmed_settings_sdk.api.system_api_api import SystemAPIApi as SystemAPIApi
    from biotmed_settings_sdk.api.template_api_api import TemplateAPIApi as TemplateAPIApi
    from biotmed_settings_sdk.api.translation_api_api import TranslationAPIApi as TranslationAPIApi
    
    # import ApiClient
    from biotmed_settings_sdk.api_response import ApiResponse as ApiResponse
    from biotmed_settings_sdk.api_client import ApiClient as ApiClient
    from biotmed_settings_sdk.configuration import Configuration as Configuration
    from biotmed_settings_sdk.exceptions import OpenApiException as OpenApiException
    from biotmed_settings_sdk.exceptions import ApiTypeError as ApiTypeError
    from biotmed_settings_sdk.exceptions import ApiValueError as ApiValueError
    from biotmed_settings_sdk.exceptions import ApiKeyError as ApiKeyError
    from biotmed_settings_sdk.exceptions import ApiAttributeError as ApiAttributeError
    from biotmed_settings_sdk.exceptions import ApiException as ApiException
    
    # import models into sdk package
    from biotmed_settings_sdk.models.add_locale_request import AddLocaleRequest as AddLocaleRequest
    from biotmed_settings_sdk.models.attribute_analytics_db_configuration import AttributeAnalyticsDbConfiguration as AttributeAnalyticsDbConfiguration
    from biotmed_settings_sdk.models.attribute_identifier import AttributeIdentifier as AttributeIdentifier
    from biotmed_settings_sdk.models.backup_request import BackupRequest as BackupRequest
    from biotmed_settings_sdk.models.backup_response import BackupResponse as BackupResponse
    from biotmed_settings_sdk.models.base_locale import BaseLocale as BaseLocale
    from biotmed_settings_sdk.models.base_selectable_value import BaseSelectableValue as BaseSelectableValue
    from biotmed_settings_sdk.models.basic_attribute_data import BasicAttributeData as BasicAttributeData
    from biotmed_settings_sdk.models.basic_template_data import BasicTemplateData as BasicTemplateData
    from biotmed_settings_sdk.models.built_in_attribute import BuiltInAttribute as BuiltInAttribute
    from biotmed_settings_sdk.models.category import Category as Category
    from biotmed_settings_sdk.models.code_snippet_response import CodeSnippetResponse as CodeSnippetResponse
    from biotmed_settings_sdk.models.create_built_in_attribute import CreateBuiltInAttribute as CreateBuiltInAttribute
    from biotmed_settings_sdk.models.create_code_snippet_request import CreateCodeSnippetRequest as CreateCodeSnippetRequest
    from biotmed_settings_sdk.models.create_custom_attribute import CreateCustomAttribute as CreateCustomAttribute
    from biotmed_settings_sdk.models.create_plugin_request import CreatePluginRequest as CreatePluginRequest
    from biotmed_settings_sdk.models.create_template_attribute import CreateTemplateAttribute as CreateTemplateAttribute
    from biotmed_settings_sdk.models.create_template_request import CreateTemplateRequest as CreateTemplateRequest
    from biotmed_settings_sdk.models.credentials import Credentials as Credentials
    from biotmed_settings_sdk.models.custom_attribute import CustomAttribute as CustomAttribute
    from biotmed_settings_sdk.models.docker_repository_temp_credentials_response import DockerRepositoryTempCredentialsResponse as DockerRepositoryTempCredentialsResponse
    from biotmed_settings_sdk.models.entity_notifiable_action import EntityNotifiableAction as EntityNotifiableAction
    from biotmed_settings_sdk.models.entity_type import EntityType as EntityType
    from biotmed_settings_sdk.models.entity_type_built_in_action import EntityTypeBuiltInAction as EntityTypeBuiltInAction
    from biotmed_settings_sdk.models.entity_type_built_in_attribute import EntityTypeBuiltInAttribute as EntityTypeBuiltInAttribute
    from biotmed_settings_sdk.models.entity_type_template_attribute import EntityTypeTemplateAttribute as EntityTypeTemplateAttribute
    from biotmed_settings_sdk.models.error_response import ErrorResponse as ErrorResponse
    from biotmed_settings_sdk.models.export_execution_response import ExportExecutionResponse as ExportExecutionResponse
    from biotmed_settings_sdk.models.exports_metadata_response import ExportsMetadataResponse as ExportsMetadataResponse
    from biotmed_settings_sdk.models.file_configuration_metadata_response import FileConfigurationMetadataResponse as FileConfigurationMetadataResponse
    from biotmed_settings_sdk.models.filter_v2 import FilterV2 as FilterV2
    from biotmed_settings_sdk.models.get_category_response import GetCategoryResponse as GetCategoryResponse
    from biotmed_settings_sdk.models.get_entity_types_response import GetEntityTypesResponse as GetEntityTypesResponse
    from biotmed_settings_sdk.models.get_notifiable_actions import GetNotifiableActions as GetNotifiableActions
    from biotmed_settings_sdk.models.get_template_response import GetTemplateResponse as GetTemplateResponse
    from biotmed_settings_sdk.models.import_execution_response import ImportExecutionResponse as ImportExecutionResponse
    from biotmed_settings_sdk.models.interception_configuration_response import InterceptionConfigurationResponse as InterceptionConfigurationResponse
    from biotmed_settings_sdk.models.interception_subscription_dto import InterceptionSubscriptionDto as InterceptionSubscriptionDto
    from biotmed_settings_sdk.models.invalid_translation import InvalidTranslation as InvalidTranslation
    from biotmed_settings_sdk.models.json_nullable_list_cors_allowed_http_method_enum import JsonNullableListCorsAllowedHttpMethodEnum as JsonNullableListCorsAllowedHttpMethodEnum
    from biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto import JsonNullableListInterceptionSubscriptionDto as JsonNullableListInterceptionSubscriptionDto
    from biotmed_settings_sdk.models.json_nullable_list_notification_subscription_dto import JsonNullableListNotificationSubscriptionDto as JsonNullableListNotificationSubscriptionDto
    from biotmed_settings_sdk.models.json_nullable_list_string import JsonNullableListString as JsonNullableListString
    from biotmed_settings_sdk.models.json_nullable_set_base_locale import JsonNullableSetBaseLocale as JsonNullableSetBaseLocale
    from biotmed_settings_sdk.models.link_configuration import LinkConfiguration as LinkConfiguration
    from biotmed_settings_sdk.models.locale_translations_coverage import LocaleTranslationsCoverage as LocaleTranslationsCoverage
    from biotmed_settings_sdk.models.locale_translations_overview import LocaleTranslationsOverview as LocaleTranslationsOverview
    from biotmed_settings_sdk.models.locales_response import LocalesResponse as LocalesResponse
    from biotmed_settings_sdk.models.metadata import Metadata as Metadata
    from biotmed_settings_sdk.models.notification_subscription_dto import NotificationSubscriptionDto as NotificationSubscriptionDto
    from biotmed_settings_sdk.models.numeric_meta_data import NumericMetaData as NumericMetaData
    from biotmed_settings_sdk.models.order import Order as Order
    from biotmed_settings_sdk.models.organization_selection import OrganizationSelection as OrganizationSelection
    from biotmed_settings_sdk.models.organization_selection_configuration import OrganizationSelectionConfiguration as OrganizationSelectionConfiguration
    from biotmed_settings_sdk.models.page_metadata import PageMetadata as PageMetadata
    from biotmed_settings_sdk.models.parent_template_response import ParentTemplateResponse as ParentTemplateResponse
    from biotmed_settings_sdk.models.partial_plugin_cors_config import PartialPluginCorsConfig as PartialPluginCorsConfig
    from biotmed_settings_sdk.models.partial_update_plugin_request import PartialUpdatePluginRequest as PartialUpdatePluginRequest
    from biotmed_settings_sdk.models.partial_update_subscription_dto import PartialUpdateSubscriptionDto as PartialUpdateSubscriptionDto
    from biotmed_settings_sdk.models.plugin_cors_config import PluginCorsConfig as PluginCorsConfig
    from biotmed_settings_sdk.models.plugin_response import PluginResponse as PluginResponse
    from biotmed_settings_sdk.models.primary_administrator import PrimaryAdministrator as PrimaryAdministrator
    from biotmed_settings_sdk.models.reference_configuration import ReferenceConfiguration as ReferenceConfiguration
    from biotmed_settings_sdk.models.reset_system_request import ResetSystemRequest as ResetSystemRequest
    from biotmed_settings_sdk.models.restore_response import RestoreResponse as RestoreResponse
    from biotmed_settings_sdk.models.search_request_v2 import SearchRequestV2 as SearchRequestV2
    from biotmed_settings_sdk.models.search_response_backup_response import SearchResponseBackupResponse as SearchResponseBackupResponse
    from biotmed_settings_sdk.models.search_response_code_snippet_response import SearchResponseCodeSnippetResponse as SearchResponseCodeSnippetResponse
    from biotmed_settings_sdk.models.search_response_entity_type import SearchResponseEntityType as SearchResponseEntityType
    from biotmed_settings_sdk.models.search_response_get_template_response import SearchResponseGetTemplateResponse as SearchResponseGetTemplateResponse
    from biotmed_settings_sdk.models.search_response_interception_configuration_response import SearchResponseInterceptionConfigurationResponse as SearchResponseInterceptionConfigurationResponse
    from biotmed_settings_sdk.models.search_response_locale_translations_overview import SearchResponseLocaleTranslationsOverview as SearchResponseLocaleTranslationsOverview
    from biotmed_settings_sdk.models.search_response_plugin_response import SearchResponsePluginResponse as SearchResponsePluginResponse
    from biotmed_settings_sdk.models.search_response_restore_response import SearchResponseRestoreResponse as SearchResponseRestoreResponse
    from biotmed_settings_sdk.models.search_response_template_minimized_response import SearchResponseTemplateMinimizedResponse as SearchResponseTemplateMinimizedResponse
    from biotmed_settings_sdk.models.selectable_value import SelectableValue as SelectableValue
    from biotmed_settings_sdk.models.selected_organization import SelectedOrganization as SelectedOrganization
    from biotmed_settings_sdk.models.start_export_configuration_request import StartExportConfigurationRequest as StartExportConfigurationRequest
    from biotmed_settings_sdk.models.start_import_configuration_request import StartImportConfigurationRequest as StartImportConfigurationRequest
    from biotmed_settings_sdk.models.subscription_dto import SubscriptionDto as SubscriptionDto
    from biotmed_settings_sdk.models.system_properties_response import SystemPropertiesResponse as SystemPropertiesResponse
    from biotmed_settings_sdk.models.template_analytics_db_configuration import TemplateAnalyticsDbConfiguration as TemplateAnalyticsDbConfiguration
    from biotmed_settings_sdk.models.template_attribute import TemplateAttribute as TemplateAttribute
    from biotmed_settings_sdk.models.template_minimized_response import TemplateMinimizedResponse as TemplateMinimizedResponse
    from biotmed_settings_sdk.models.template_overview_response import TemplateOverviewResponse as TemplateOverviewResponse
    from biotmed_settings_sdk.models.template_statistics import TemplateStatistics as TemplateStatistics
    from biotmed_settings_sdk.models.update_built_in_attribute import UpdateBuiltInAttribute as UpdateBuiltInAttribute
    from biotmed_settings_sdk.models.update_custom_attribute import UpdateCustomAttribute as UpdateCustomAttribute
    from biotmed_settings_sdk.models.update_locale_translations_response import UpdateLocaleTranslationsResponse as UpdateLocaleTranslationsResponse
    from biotmed_settings_sdk.models.update_locales_request import UpdateLocalesRequest as UpdateLocalesRequest
    from biotmed_settings_sdk.models.update_template_attribute import UpdateTemplateAttribute as UpdateTemplateAttribute
    from biotmed_settings_sdk.models.update_template_request import UpdateTemplateRequest as UpdateTemplateRequest
    from biotmed_settings_sdk.models.validate_locale_translations_response import ValidateLocaleTranslationsResponse as ValidateLocaleTranslationsResponse
    from biotmed_settings_sdk.models.validation_definition_metadata_object import ValidationDefinitionMetadataObject as ValidationDefinitionMetadataObject
    from biotmed_settings_sdk.models.validation_definition_object import ValidationDefinitionObject as ValidationDefinitionObject
    from biotmed_settings_sdk.models.version_response import VersionResponse as VersionResponse
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            ("__version__", __version__),
            ("__all__", __all__),
            """# import apis into sdk package
from biotmed_settings_sdk.api.backup_api_api import BackupAPIApi as BackupAPIApi
from biotmed_settings_sdk.api.code_snippet_api_api import CodeSnippetAPIApi as CodeSnippetAPIApi
from biotmed_settings_sdk.api.entity_api_api import EntityAPIApi as EntityAPIApi
from biotmed_settings_sdk.api.export_import_configuration_api_api import ExportImportConfigurationAPIApi as ExportImportConfigurationAPIApi
from biotmed_settings_sdk.api.health_check_api_api import HealthCheckAPIApi as HealthCheckAPIApi
from biotmed_settings_sdk.api.interception_configuration_api_api import InterceptionConfigurationAPIApi as InterceptionConfigurationAPIApi
from biotmed_settings_sdk.api.locale_api_api import LocaleAPIApi as LocaleAPIApi
from biotmed_settings_sdk.api.plugin_v2_api_api import PluginV2APIApi as PluginV2APIApi
from biotmed_settings_sdk.api.system_api_api import SystemAPIApi as SystemAPIApi
from biotmed_settings_sdk.api.template_api_api import TemplateAPIApi as TemplateAPIApi
from biotmed_settings_sdk.api.translation_api_api import TranslationAPIApi as TranslationAPIApi

# import ApiClient
from biotmed_settings_sdk.api_response import ApiResponse as ApiResponse
from biotmed_settings_sdk.api_client import ApiClient as ApiClient
from biotmed_settings_sdk.configuration import Configuration as Configuration
from biotmed_settings_sdk.exceptions import OpenApiException as OpenApiException
from biotmed_settings_sdk.exceptions import ApiTypeError as ApiTypeError
from biotmed_settings_sdk.exceptions import ApiValueError as ApiValueError
from biotmed_settings_sdk.exceptions import ApiKeyError as ApiKeyError
from biotmed_settings_sdk.exceptions import ApiAttributeError as ApiAttributeError
from biotmed_settings_sdk.exceptions import ApiException as ApiException

# import models into sdk package
from biotmed_settings_sdk.models.add_locale_request import AddLocaleRequest as AddLocaleRequest
from biotmed_settings_sdk.models.attribute_analytics_db_configuration import AttributeAnalyticsDbConfiguration as AttributeAnalyticsDbConfiguration
from biotmed_settings_sdk.models.attribute_identifier import AttributeIdentifier as AttributeIdentifier
from biotmed_settings_sdk.models.backup_request import BackupRequest as BackupRequest
from biotmed_settings_sdk.models.backup_response import BackupResponse as BackupResponse
from biotmed_settings_sdk.models.base_locale import BaseLocale as BaseLocale
from biotmed_settings_sdk.models.base_selectable_value import BaseSelectableValue as BaseSelectableValue
from biotmed_settings_sdk.models.basic_attribute_data import BasicAttributeData as BasicAttributeData
from biotmed_settings_sdk.models.basic_template_data import BasicTemplateData as BasicTemplateData
from biotmed_settings_sdk.models.built_in_attribute import BuiltInAttribute as BuiltInAttribute
from biotmed_settings_sdk.models.category import Category as Category
from biotmed_settings_sdk.models.code_snippet_response import CodeSnippetResponse as CodeSnippetResponse
from biotmed_settings_sdk.models.create_built_in_attribute import CreateBuiltInAttribute as CreateBuiltInAttribute
from biotmed_settings_sdk.models.create_code_snippet_request import CreateCodeSnippetRequest as CreateCodeSnippetRequest
from biotmed_settings_sdk.models.create_custom_attribute import CreateCustomAttribute as CreateCustomAttribute
from biotmed_settings_sdk.models.create_plugin_request import CreatePluginRequest as CreatePluginRequest
from biotmed_settings_sdk.models.create_template_attribute import CreateTemplateAttribute as CreateTemplateAttribute
from biotmed_settings_sdk.models.create_template_request import CreateTemplateRequest as CreateTemplateRequest
from biotmed_settings_sdk.models.credentials import Credentials as Credentials
from biotmed_settings_sdk.models.custom_attribute import CustomAttribute as CustomAttribute
from biotmed_settings_sdk.models.docker_repository_temp_credentials_response import DockerRepositoryTempCredentialsResponse as DockerRepositoryTempCredentialsResponse
from biotmed_settings_sdk.models.entity_notifiable_action import EntityNotifiableAction as EntityNotifiableAction
from biotmed_settings_sdk.models.entity_type import EntityType as EntityType
from biotmed_settings_sdk.models.entity_type_built_in_action import EntityTypeBuiltInAction as EntityTypeBuiltInAction
from biotmed_settings_sdk.models.entity_type_built_in_attribute import EntityTypeBuiltInAttribute as EntityTypeBuiltInAttribute
from biotmed_settings_sdk.models.entity_type_template_attribute import EntityTypeTemplateAttribute as EntityTypeTemplateAttribute
from biotmed_settings_sdk.models.error_response import ErrorResponse as ErrorResponse
from biotmed_settings_sdk.models.export_execution_response import ExportExecutionResponse as ExportExecutionResponse
from biotmed_settings_sdk.models.exports_metadata_response import ExportsMetadataResponse as ExportsMetadataResponse
from biotmed_settings_sdk.models.file_configuration_metadata_response import FileConfigurationMetadataResponse as FileConfigurationMetadataResponse
from biotmed_settings_sdk.models.filter_v2 import FilterV2 as FilterV2
from biotmed_settings_sdk.models.get_category_response import GetCategoryResponse as GetCategoryResponse
from biotmed_settings_sdk.models.get_entity_types_response import GetEntityTypesResponse as GetEntityTypesResponse
from biotmed_settings_sdk.models.get_notifiable_actions import GetNotifiableActions as GetNotifiableActions
from biotmed_settings_sdk.models.get_template_response import GetTemplateResponse as GetTemplateResponse
from biotmed_settings_sdk.models.import_execution_response import ImportExecutionResponse as ImportExecutionResponse
from biotmed_settings_sdk.models.interception_configuration_response import InterceptionConfigurationResponse as InterceptionConfigurationResponse
from biotmed_settings_sdk.models.interception_subscription_dto import InterceptionSubscriptionDto as InterceptionSubscriptionDto
from biotmed_settings_sdk.models.invalid_translation import InvalidTranslation as InvalidTranslation
from biotmed_settings_sdk.models.json_nullable_list_cors_allowed_http_method_enum import JsonNullableListCorsAllowedHttpMethodEnum as JsonNullableListCorsAllowedHttpMethodEnum
from biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto import JsonNullableListInterceptionSubscriptionDto as JsonNullableListInterceptionSubscriptionDto
from biotmed_settings_sdk.models.json_nullable_list_notification_subscription_dto import JsonNullableListNotificationSubscriptionDto as JsonNullableListNotificationSubscriptionDto
from biotmed_settings_sdk.models.json_nullable_list_string import JsonNullableListString as JsonNullableListString
from biotmed_settings_sdk.models.json_nullable_set_base_locale import JsonNullableSetBaseLocale as JsonNullableSetBaseLocale
from biotmed_settings_sdk.models.link_configuration import LinkConfiguration as LinkConfiguration
from biotmed_settings_sdk.models.locale_translations_coverage import LocaleTranslationsCoverage as LocaleTranslationsCoverage
from biotmed_settings_sdk.models.locale_translations_overview import LocaleTranslationsOverview as LocaleTranslationsOverview
from biotmed_settings_sdk.models.locales_response import LocalesResponse as LocalesResponse
from biotmed_settings_sdk.models.metadata import Metadata as Metadata
from biotmed_settings_sdk.models.notification_subscription_dto import NotificationSubscriptionDto as NotificationSubscriptionDto
from biotmed_settings_sdk.models.numeric_meta_data import NumericMetaData as NumericMetaData
from biotmed_settings_sdk.models.order import Order as Order
from biotmed_settings_sdk.models.organization_selection import OrganizationSelection as OrganizationSelection
from biotmed_settings_sdk.models.organization_selection_configuration import OrganizationSelectionConfiguration as OrganizationSelectionConfiguration
from biotmed_settings_sdk.models.page_metadata import PageMetadata as PageMetadata
from biotmed_settings_sdk.models.parent_template_response import ParentTemplateResponse as ParentTemplateResponse
from biotmed_settings_sdk.models.partial_plugin_cors_config import PartialPluginCorsConfig as PartialPluginCorsConfig
from biotmed_settings_sdk.models.partial_update_plugin_request import PartialUpdatePluginRequest as PartialUpdatePluginRequest
from biotmed_settings_sdk.models.partial_update_subscription_dto import PartialUpdateSubscriptionDto as PartialUpdateSubscriptionDto
from biotmed_settings_sdk.models.plugin_cors_config import PluginCorsConfig as PluginCorsConfig
from biotmed_settings_sdk.models.plugin_response import PluginResponse as PluginResponse
from biotmed_settings_sdk.models.primary_administrator import PrimaryAdministrator as PrimaryAdministrator
from biotmed_settings_sdk.models.reference_configuration import ReferenceConfiguration as ReferenceConfiguration
from biotmed_settings_sdk.models.reset_system_request import ResetSystemRequest as ResetSystemRequest
from biotmed_settings_sdk.models.restore_response import RestoreResponse as RestoreResponse
from biotmed_settings_sdk.models.search_request_v2 import SearchRequestV2 as SearchRequestV2
from biotmed_settings_sdk.models.search_response_backup_response import SearchResponseBackupResponse as SearchResponseBackupResponse
from biotmed_settings_sdk.models.search_response_code_snippet_response import SearchResponseCodeSnippetResponse as SearchResponseCodeSnippetResponse
from biotmed_settings_sdk.models.search_response_entity_type import SearchResponseEntityType as SearchResponseEntityType
from biotmed_settings_sdk.models.search_response_get_template_response import SearchResponseGetTemplateResponse as SearchResponseGetTemplateResponse
from biotmed_settings_sdk.models.search_response_interception_configuration_response import SearchResponseInterceptionConfigurationResponse as SearchResponseInterceptionConfigurationResponse
from biotmed_settings_sdk.models.search_response_locale_translations_overview import SearchResponseLocaleTranslationsOverview as SearchResponseLocaleTranslationsOverview
from biotmed_settings_sdk.models.search_response_plugin_response import SearchResponsePluginResponse as SearchResponsePluginResponse
from biotmed_settings_sdk.models.search_response_restore_response import SearchResponseRestoreResponse as SearchResponseRestoreResponse
from biotmed_settings_sdk.models.search_response_template_minimized_response import SearchResponseTemplateMinimizedResponse as SearchResponseTemplateMinimizedResponse
from biotmed_settings_sdk.models.selectable_value import SelectableValue as SelectableValue
from biotmed_settings_sdk.models.selected_organization import SelectedOrganization as SelectedOrganization
from biotmed_settings_sdk.models.start_export_configuration_request import StartExportConfigurationRequest as StartExportConfigurationRequest
from biotmed_settings_sdk.models.start_import_configuration_request import StartImportConfigurationRequest as StartImportConfigurationRequest
from biotmed_settings_sdk.models.subscription_dto import SubscriptionDto as SubscriptionDto
from biotmed_settings_sdk.models.system_properties_response import SystemPropertiesResponse as SystemPropertiesResponse
from biotmed_settings_sdk.models.template_analytics_db_configuration import TemplateAnalyticsDbConfiguration as TemplateAnalyticsDbConfiguration
from biotmed_settings_sdk.models.template_attribute import TemplateAttribute as TemplateAttribute
from biotmed_settings_sdk.models.template_minimized_response import TemplateMinimizedResponse as TemplateMinimizedResponse
from biotmed_settings_sdk.models.template_overview_response import TemplateOverviewResponse as TemplateOverviewResponse
from biotmed_settings_sdk.models.template_statistics import TemplateStatistics as TemplateStatistics
from biotmed_settings_sdk.models.update_built_in_attribute import UpdateBuiltInAttribute as UpdateBuiltInAttribute
from biotmed_settings_sdk.models.update_custom_attribute import UpdateCustomAttribute as UpdateCustomAttribute
from biotmed_settings_sdk.models.update_locale_translations_response import UpdateLocaleTranslationsResponse as UpdateLocaleTranslationsResponse
from biotmed_settings_sdk.models.update_locales_request import UpdateLocalesRequest as UpdateLocalesRequest
from biotmed_settings_sdk.models.update_template_attribute import UpdateTemplateAttribute as UpdateTemplateAttribute
from biotmed_settings_sdk.models.update_template_request import UpdateTemplateRequest as UpdateTemplateRequest
from biotmed_settings_sdk.models.validate_locale_translations_response import ValidateLocaleTranslationsResponse as ValidateLocaleTranslationsResponse
from biotmed_settings_sdk.models.validation_definition_metadata_object import ValidationDefinitionMetadataObject as ValidationDefinitionMetadataObject
from biotmed_settings_sdk.models.validation_definition_object import ValidationDefinitionObject as ValidationDefinitionObject
from biotmed_settings_sdk.models.version_response import VersionResponse as VersionResponse

""",
            name=__name__,
            doc=__doc__,
        )
    )



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.get_template_response import GetTemplateResponse

class TestGetTemplateResponse(unittest.TestCase):
    """GetTemplateResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetTemplateResponse:
        """Test GetTemplateResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetTemplateResponse`
        """
        model = GetTemplateResponse()
        if include_optional:
            return GetTemplateResponse(
                display_name = '0',
                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0',
                description = '0',
                owner_organization_id = '',
                analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                    name = '', ),
                id = '',
                entity_type_name = '',
                removable = True,
                creation_time = '2007-12-20T10:15:30Z',
                last_modified_time = '2007-12-20T10:15:30Z',
                parent_template = biotmed_settings_sdk.models.parent_template_response.ParentTemplateResponse(
                    id = '', 
                    display_name = '', 
                    name = '', ),
                parent_template_id = '',
                custom_attributes = [
                    biotmed_settings_sdk.models.custom_attribute.CustomAttribute(
                        display_name = '0', 
                        phi = True, 
                        reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                            uniquely = True, 
                            referenced_side_attribute_name = '', 
                            referenced_side_attribute_display_name = '', 
                            valid_templates_to_reference = [
                                ''
                                ], 
                            entity_type = '', ), 
                        link_configuration = biotmed_settings_sdk.models.link_configuration.LinkConfiguration(
                            entity_type_name = '', 
                            template_id = '', 
                            attribute_id = '', ), 
                        name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0', 
                        type = 'LABEL', 
                        validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                            mandatory = True, 
                            default_value = null, 
                            min = -9223372036854775808, 
                            max = -9223372036854775808, 
                            regex = '', ), 
                        numeric_meta_data = biotmed_settings_sdk.models.numeric_meta_data.NumericMetaData(
                            units = '', 
                            upper_range = -2147483648, 
                            lower_range = -2147483648, 
                            sub_type = 'INTEGER', ), 
                        analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                            name = '', ), 
                        id = '', 
                        selectable_values = [
                            biotmed_settings_sdk.models.selectable_value.SelectableValue(
                                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua', 
                                display_name = '', 
                                id = '', )
                            ], 
                        category = biotmed_settings_sdk.models.category.Category(
                            name = '', 
                            display_name = '', ), 
                        base_path = '', 
                        type_enum = 'LABEL', )
                    ],
                built_in_attributes = [
                    biotmed_settings_sdk.models.built_in_attribute.BuiltInAttribute(
                        name = '', 
                        base_path = '', 
                        id = '', 
                        display_name = '0', 
                        phi = True, 
                        reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                            uniquely = True, 
                            referenced_side_attribute_name = '', 
                            referenced_side_attribute_display_name = '', 
                            valid_templates_to_reference = [
                                ''
                                ], 
                            entity_type = '', ), 
                        link_configuration = biotmed_settings_sdk.models.link_configuration.LinkConfiguration(
                            entity_type_name = '', 
                            template_id = '', 
                            attribute_id = '', ), 
                        validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                            mandatory = True, 
                            default_value = null, 
                            min = -9223372036854775808, 
                            max = -9223372036854775808, 
                            regex = '', ), 
                        numeric_meta_data = biotmed_settings_sdk.models.numeric_meta_data.NumericMetaData(
                            units = '', 
                            upper_range = -2147483648, 
                            lower_range = -2147483648, 
                            sub_type = 'INTEGER', ), 
                        type = 'LABEL', 
                        category = biotmed_settings_sdk.models.category.Category(
                            name = '', 
                            display_name = '', ), 
                        validation_metadata = biotmed_settings_sdk.models.validation_definition_metadata_object.ValidationDefinitionMetadataObject(
                            mandatory_read_only = True, 
                            system_mandatory = True, 
                            phi_read_only = True, ), 
                        selectable_values = [
                            biotmed_settings_sdk.models.base_selectable_value.BaseSelectableValue(
                                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua', 
                                display_name = '', )
                            ], 
                        read_only = True, 
                        analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                            name = '', ), 
                        type_enum = 'LABEL', )
                    ],
                template_attributes = [
                    biotmed_settings_sdk.models.template_attribute.TemplateAttribute(
                        name = '', 
                        base_path = '', 
                        id = '', 
                        display_name = '0', 
                        phi = True, 
                        reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                            uniquely = True, 
                            referenced_side_attribute_name = '', 
                            referenced_side_attribute_display_name = '', 
                            valid_templates_to_reference = [
                                ''
                                ], 
                            entity_type = '', ), 
                        link_configuration = biotmed_settings_sdk.models.link_configuration.LinkConfiguration(
                            entity_type_name = '', 
                            template_id = '', 
                            attribute_id = '', ), 
                        value = null, 
                        type = 'LABEL', 
                        category = biotmed_settings_sdk.models.category.Category(
                            name = '', 
                            display_name = '', ), 
                        selectable_values = [
                            biotmed_settings_sdk.models.base_selectable_value.BaseSelectableValue(
                                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua', 
                                display_name = '', )
                            ], 
                        validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                            mandatory = True, 
                            default_value = null, 
                            min = -9223372036854775808, 
                            max = -9223372036854775808, 
                            regex = '', ), 
                        numeric_meta_data = biotmed_settings_sdk.models.numeric_meta_data.NumericMetaData(
                            units = '', 
                            upper_range = -2147483648, 
                            lower_range = -2147483648, 
                            sub_type = 'INTEGER', ), 
                        organization_selection = biotmed_settings_sdk.models.organization_selection.OrganizationSelection(
                            allowed = True, 
                            configuration = biotmed_settings_sdk.models.organization_selection_configuration.OrganizationSelectionConfiguration(
                                selected = [
                                    biotmed_settings_sdk.models.selected_organization.SelectedOrganization(
                                        id = '', )
                                    ], 
                                all = True, ), ), 
                        type_enum = 'LABEL', )
                    ]
            )
        else:
            return GetTemplateResponse(
                display_name = '0',
                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0',
                creation_time = '2007-12-20T10:15:30Z',
                last_modified_time = '2007-12-20T10:15:30Z',
        )
        """

    def testGetTemplateResponse(self):
        """Test GetTemplateResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing_extensions import Annotated
from biotmed_settings_sdk.models.add_locale_request import AddLocaleRequest
from biotmed_settings_sdk.models.locales_response import LocalesResponse
from biotmed_settings_sdk.models.update_locales_request import UpdateLocalesRequest

from biotmed_settings_sdk.api_client import ApiClient, RequestSerialized
from biotmed_settings_sdk.api_response import ApiResponse
from biotmed_settings_sdk.rest import RESTResponseType


class LocaleAPIApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def add_locale(
        self,
        add_locale_request: AddLocaleRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> LocalesResponse:
        """Add locale to the available locales

        Add locale to the available locales    Locale codes are lowercase formatted and using '-' between country code and language, for example: 'en-us'   Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |code|string|true|Locale in the following format: {language-ISO639}-{countryCode-ISO3166} lowercase.|en-us| |hidden|boolean|false||false| |translationFallbackTypes|array|false|Valid array values: DEFAULT_LOCALE,SYSTEM_LOCALE. Allow to control the fallback mechanism. If not provided(null) then the default behavior is the following fallback order: -> DEFAULT_LOCALE -> SYSTEM_LOCALE. The recommended value is null. When all of the fallback types return an empty value, no translation will be made, i.e. the original value will be retained||   This API requires **SETTINGS_CREATE_LOCALE** permission(s).  

        :param add_locale_request: (required)
        :type add_locale_request: AddLocaleRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_locale_serialize(
            add_locale_request=add_locale_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '201': "LocalesResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def add_locale_with_http_info(
        self,
        add_locale_request: AddLocaleRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[LocalesResponse]:
        """Add locale to the available locales

        Add locale to the available locales    Locale codes are lowercase formatted and using '-' between country code and language, for example: 'en-us'   Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |code|string|true|Locale in the following format: {language-ISO639}-{countryCode-ISO3166} lowercase.|en-us| |hidden|boolean|false||false| |translationFallbackTypes|array|false|Valid array values: DEFAULT_LOCALE,SYSTEM_LOCALE. Allow to control the fallback mechanism. If not provided(null) then the default behavior is the following fallback order: -> DEFAULT_LOCALE -> SYSTEM_LOCALE. The recommended value is null. When all of the fallback types return an empty value, no translation will be made, i.e. the original value will be retained||   This API requires **SETTINGS_CREATE_LOCALE** permission(s).  

        :param add_locale_request: (required)
        :type add_locale_request: AddLocaleRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_locale_serialize(
            add_locale_request=add_locale_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '201': "LocalesResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def add_locale_without_preload_content(
        self,
        add_locale_request: AddLocaleRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Add locale to the available locales

        Add locale to the available locales    Locale codes are lowercase formatted and using '-' between country code and language, for example: 'en-us'   Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |code|string|true|Locale in the following format: {language-ISO639}-{countryCode-ISO3166} lowercase.|en-us| |hidden|boolean|false||false| |translationFallbackTypes|array|false|Valid array values: DEFAULT_LOCALE,SYSTEM_LOCALE. Allow to control the fallback mechanism. If not provided(null) then the default behavior is the following fallback order: -> DEFAULT_LOCALE -> SYSTEM_LOCALE. The recommended value is null. When all of the fallback types return an empty value, no translation will be made, i.e. the original value will be retained||   This API requires **SETTINGS_CREATE_LOCALE** permission(s).  

        :param add_locale_request: (required)
        :type add_locale_request: AddLocaleRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_locale_serialize(
            add_locale_request=add_locale_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '201': "LocalesResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _add_locale_serialize(
        self,
        add_locale_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if add_locale_request is not None:
            _body_params = add_locale_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/locales',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_locale(
        self,
        id: Annotated[StrictStr, Field(description="Locale ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> LocalesResponse:
        """Remove a locale from the available locales

        Remove a locale from the available locales    Path param 'id' refers to the locale code. If the provided id not exist status 200 is returned. Cannot delete the system locale. Cannot delete the default locale. If you wish to delete the default locale First you need to change the default to another one. Locale codes are lowercase formatted and using '-' between country code and language, for example: 'en-us'   Path Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |id|string|true|Locale ID||   This API requires **SETTINGS_DELETE_LOCALE** permission(s).  

        :param id: Locale ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_locale_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "LocalesResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_locale_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Locale ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[LocalesResponse]:
        """Remove a locale from the available locales

        Remove a locale from the available locales    Path param 'id' refers to the locale code. If the provided id not exist status 200 is returned. Cannot delete the system locale. Cannot delete the default locale. If you wish to delete the default locale First you need to change the default to another one. Locale codes are lowercase formatted and using '-' between country code and language, for example: 'en-us'   Path Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |id|string|true|Locale ID||   This API requires **SETTINGS_DELETE_LOCALE** permission(s).  

        :param id: Locale ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_locale_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "LocalesResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_locale_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Locale ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Remove a locale from the available locales

        Remove a locale from the available locales    Path param 'id' refers to the locale code. If the provided id not exist status 200 is returned. Cannot delete the system locale. Cannot delete the default locale. If you wish to delete the default locale First you need to change the default to another one. Locale codes are lowercase formatted and using '-' between country code and language, for example: 'en-us'   Path Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |id|string|true|Locale ID||   This API requires **SETTINGS_DELETE_LOCALE** permission(s).  

        :param id: Locale ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_locale_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "LocalesResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_locale_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/v1/locales/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_locales(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> LocalesResponse:
        """Get available locales, the default locale and the system locale

        Get available locales, the default locale and the system locale    Locale codes are lowercase formatted and using '-' between country code and language, for example: 'en-us'    This API is **public**.  

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_locales_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "LocalesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_locales_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[LocalesResponse]:
        """Get available locales, the default locale and the system locale

        Get available locales, the default locale and the system locale    Locale codes are lowercase formatted and using '-' between country code and language, for example: 'en-us'    This API is **public**.  

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_locales_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "LocalesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_locales_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get available locales, the default locale and the system locale

        Get available locales, the default locale and the system locale    Locale codes are lowercase formatted and using '-' between country code and language, for example: 'en-us'    This API is **public**.  

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_locales_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "LocalesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_locales_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/locales/configuration',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_locales(
        self,
        update_locales_request: UpdateLocalesRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> LocalesResponse:
        """Update available locales and/or the system default locale.

        Update available locales and/or the system default locale.    Locale codes are lowercase formatted and using '-' between country code and language, for example: 'en-us'. If the availableLocales was provided it must contain the system locale en-us because it cannot be removed. IF 'defaultLocale' was provided it must be exist in the availableLocales list. If availableLocales is not provided the default locale must be exist before setting it as default   (*)This parameter is mandatory only if its optional parent attribute is defined. Click <a href=\"https://docs.biot-med.com/docs/biot-rest-api#api-optional-parameters\" target=\"_blank\">here</a> for more information.  Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |availableLocales|array|false||| |availableLocales[index]|array|false||| |availableLocales[index].code|string|true(*)|Locale in the following format: {language-ISO639}-{countryCode-ISO3166} lowercase.|en-us| |availableLocales[index].hidden|boolean|false||false| |availableLocales[index].translationFallbackTypes|array|false|Valid array values: DEFAULT_LOCALE,SYSTEM_LOCALE. Allow to control the fallback mechanism. If not provided(null) then the default behavior is the following fallback order: -> DEFAULT_LOCALE -> SYSTEM_LOCALE. The recommended value is null. When all of the fallback types return an empty value, no translation will be made, i.e. the original value will be retained|| |defaultLocaleCode|string|false|Locale in the following format: {language-ISO639}-{countryCode-ISO3166} lowercase.|en-us|   This API requires **SETTINGS_UPDATE_LOCALES** permission(s).  

        :param update_locales_request: (required)
        :type update_locales_request: UpdateLocalesRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_locales_serialize(
            update_locales_request=update_locales_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "LocalesResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_locales_with_http_info(
        self,
        update_locales_request: UpdateLocalesRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[LocalesResponse]:
        """Update available locales and/or the system default locale.

        Update available locales and/or the system default locale.    Locale codes are lowercase formatted and using '-' between country code and language, for example: 'en-us'. If the availableLocales was provided it must contain the system locale en-us because it cannot be removed. IF 'defaultLocale' was provided it must be exist in the availableLocales list. If availableLocales is not provided the default locale must be exist before setting it as default   (*)This parameter is mandatory only if its optional parent attribute is defined. Click <a href=\"https://docs.biot-med.com/docs/biot-rest-api#api-optional-parameters\" target=\"_blank\">here</a> for more information.  Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |availableLocales|array|false||| |availableLocales[index]|array|false||| |availableLocales[index].code|string|true(*)|Locale in the following format: {language-ISO639}-{countryCode-ISO3166} lowercase.|en-us| |availableLocales[index].hidden|boolean|false||false| |availableLocales[index].translationFallbackTypes|array|false|Valid array values: DEFAULT_LOCALE,SYSTEM_LOCALE. Allow to control the fallback mechanism. If not provided(null) then the default behavior is the following fallback order: -> DEFAULT_LOCALE -> SYSTEM_LOCALE. The recommended value is null. When all of the fallback types return an empty value, no translation will be made, i.e. the original value will be retained|| |defaultLocaleCode|string|false|Locale in the following format: {language-ISO639}-{countryCode-ISO3166} lowercase.|en-us|   This API requires **SETTINGS_UPDATE_LOCALES** permission(s).  

        :param update_locales_request: (required)
        :type update_locales_request: UpdateLocalesRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_locales_serialize(
            update_locales_request=update_locales_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "LocalesResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_locales_without_preload_content(
        self,
        update_locales_request: UpdateLocalesRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update available locales and/or the system default locale.

        Update available locales and/or the system default locale.    Locale codes are lowercase formatted and using '-' between country code and language, for example: 'en-us'. If the availableLocales was provided it must contain the system locale en-us because it cannot be removed. IF 'defaultLocale' was provided it must be exist in the availableLocales list. If availableLocales is not provided the default locale must be exist before setting it as default   (*)This parameter is mandatory only if its optional parent attribute is defined. Click <a href=\"https://docs.biot-med.com/docs/biot-rest-api#api-optional-parameters\" target=\"_blank\">here</a> for more information.  Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |availableLocales|array|false||| |availableLocales[index]|array|false||| |availableLocales[index].code|string|true(*)|Locale in the following format: {language-ISO639}-{countryCode-ISO3166} lowercase.|en-us| |availableLocales[index].hidden|boolean|false||false| |availableLocales[index].translationFallbackTypes|array|false|Valid array values: DEFAULT_LOCALE,SYSTEM_LOCALE. Allow to control the fallback mechanism. If not provided(null) then the default behavior is the following fallback order: -> DEFAULT_LOCALE -> SYSTEM_LOCALE. The recommended value is null. When all of the fallback types return an empty value, no translation will be made, i.e. the original value will be retained|| |defaultLocaleCode|string|false|Locale in the following format: {language-ISO639}-{countryCode-ISO3166} lowercase.|en-us|   This API requires **SETTINGS_UPDATE_LOCALES** permission(s).  

        :param update_locales_request: (required)
        :type update_locales_request: UpdateLocalesRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_locales_serialize(
            update_locales_request=update_locales_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "LocalesResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_locales_serialize(
        self,
        update_locales_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if update_locales_request is not None:
            _body_params = update_locales_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/v1/locales/configuration',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.get_entity_types_response import GetEntityTypesResponse

class TestGetEntityTypesResponse(unittest.TestCase):
    """GetEntityTypesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetEntityTypesResponse:
        """Test GetEntityTypesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetEntityTypesResponse`
        """
        model = GetEntityTypesResponse()
        if include_optional:
            return GetEntityTypesResponse(
                entity_types = [
                    biotmed_settings_sdk.models.entity_type.EntityType(
                        name = '', 
                        display_name = '', 
                        built_in_actions = [
                            biotmed_settings_sdk.models.entity_type_built_in_action.EntityTypeBuiltInAction(
                                name = '', 
                                base_path = '', 
                                display_name = '', 
                                enable_notification = True, 
                                enable_log = True, 
                                timeout_in_seconds = 56, 
                                source = '', 
                                category = biotmed_settings_sdk.models.category.Category(
                                    name = '', 
                                    display_name = '', ), )
                            ], 
                        children = [
                            biotmed_settings_sdk.models.entity_type.EntityType(
                                name = '', 
                                display_name = '', 
                                attribute_categories = [
                                    biotmed_settings_sdk.models.get_category_response.GetCategoryResponse(
                                        name = '', 
                                        display_name = '', 
                                        built_in_supported_types = [
                                            'LABEL'
                                            ], 
                                        custom_supported_types = [
                                            'LABEL'
                                            ], 
                                        allowed_categories_to_link_to = [
                                            ''
                                            ], 
                                        support_mandatory_validation = True, 
                                        custom_base_path = '', )
                                    ], 
                                built_in_attributes = [
                                    biotmed_settings_sdk.models.entity_type_built_in_attribute.EntityTypeBuiltInAttribute(
                                        name = '', 
                                        base_path = '', 
                                        type = 'LABEL', 
                                        display_name = '', 
                                        phi = True, 
                                        validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                                            mandatory = True, 
                                            default_value = null, 
                                            min = -9223372036854775808, 
                                            max = -9223372036854775808, 
                                            regex = '', ), 
                                        validation_metadata = biotmed_settings_sdk.models.validation_definition_metadata_object.ValidationDefinitionMetadataObject(
                                            mandatory_read_only = True, 
                                            system_mandatory = True, 
                                            phi_read_only = True, ), 
                                        selectable_values = [
                                            biotmed_settings_sdk.models.base_selectable_value.BaseSelectableValue(
                                                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua', 
                                                display_name = '', )
                                            ], 
                                        read_only = True, 
                                        reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                                            uniquely = True, 
                                            referenced_side_attribute_name = '', 
                                            referenced_side_attribute_display_name = '', 
                                            valid_templates_to_reference = [
                                                ''
                                                ], 
                                            entity_type = '', ), 
                                        numeric_meta_data = biotmed_settings_sdk.models.numeric_meta_data.NumericMetaData(
                                            units = '', 
                                            upper_range = -2147483648, 
                                            lower_range = -2147483648, 
                                            sub_type = 'INTEGER', ), 
                                        analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                                            name = '', ), 
                                        type_enum = 'LABEL', )
                                    ], 
                                template_attributes = [
                                    biotmed_settings_sdk.models.entity_type_template_attribute.EntityTypeTemplateAttribute(
                                        name = '', 
                                        base_path = '', 
                                        type = 'LABEL', 
                                        display_name = '', 
                                        phi = True, 
                                        validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                                            mandatory = True, 
                                            default_value = null, 
                                            min = -9223372036854775808, 
                                            max = -9223372036854775808, 
                                            regex = '', ), 
                                        value = null, 
                                        organization_selection = biotmed_settings_sdk.models.organization_selection.OrganizationSelection(
                                            allowed = True, 
                                            configuration = biotmed_settings_sdk.models.organization_selection_configuration.OrganizationSelectionConfiguration(
                                                selected = [
                                                    biotmed_settings_sdk.models.selected_organization.SelectedOrganization(
                                                        id = '', )
                                                    ], 
                                                all = True, ), ), 
                                        category = biotmed_settings_sdk.models.category.Category(
                                            name = '', 
                                            display_name = '', ), 
                                        type_enum = 'LABEL', )
                                    ], 
                                parent_template_type = '', 
                                caption_attributes = [
                                    biotmed_settings_sdk.models.attribute_identifier.AttributeIdentifier(
                                        name = '', 
                                        base_path = '', )
                                    ], 
                                reserved_template_names = [
                                    ''
                                    ], 
                                adding_custom_attribute_reference_type_supported = True, 
                                adding_templates_supported = True, )
                            ], 
                        attribute_categories = [
                            biotmed_settings_sdk.models.get_category_response.GetCategoryResponse(
                                name = '', 
                                display_name = '', 
                                support_mandatory_validation = True, 
                                custom_base_path = '', )
                            ], 
                        built_in_attributes = [
                            biotmed_settings_sdk.models.entity_type_built_in_attribute.EntityTypeBuiltInAttribute(
                                name = '', 
                                base_path = '', 
                                type = 'LABEL', 
                                display_name = '', 
                                phi = True, 
                                read_only = True, 
                                type_enum = 'LABEL', )
                            ], 
                        template_attributes = [
                            biotmed_settings_sdk.models.entity_type_template_attribute.EntityTypeTemplateAttribute(
                                name = '', 
                                base_path = '', 
                                type = 'LABEL', 
                                display_name = '', 
                                phi = True, 
                                validation = , 
                                value = null, 
                                category = , 
                                type_enum = 'LABEL', )
                            ], 
                        parent_template_type = '', 
                        caption_attributes = [
                            biotmed_settings_sdk.models.attribute_identifier.AttributeIdentifier(
                                name = '', 
                                base_path = '', )
                            ], 
                        reserved_template_names = [
                            ''
                            ], 
                        adding_custom_attribute_reference_type_supported = True, 
                        adding_templates_supported = True, )
                    ]
            )
        else:
            return GetEntityTypesResponse(
        )
        """

    def testGetEntityTypesResponse(self):
        """Test GetEntityTypesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.subscription_dto import SubscriptionDto

class TestSubscriptionDto(unittest.TestCase):
    """SubscriptionDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SubscriptionDto:
        """Test SubscriptionDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SubscriptionDto`
        """
        model = SubscriptionDto()
        if include_optional:
            return SubscriptionDto(
                interception_order = 56,
                interceptions = [
                    biotmed_settings_sdk.models.interception_subscription_dto.InterceptionSubscriptionDto(
                        type = 'PRE_REQUEST', 
                        api_id = '', 
                        entity_type_name = 'device', 
                        order = 56, )
                    ],
                notifications = [
                    biotmed_settings_sdk.models.notification_subscription_dto.NotificationSubscriptionDto(
                        entity_type_name = 'device', 
                        action_name = '_create', )
                    ]
            )
        else:
            return SubscriptionDto(
        )
        """

    def testSubscriptionDto(self):
        """Test SubscriptionDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

if __import__("typing").TYPE_CHECKING:
    # import apis into api package
    from biotmed_settings_sdk.api.backup_api_api import BackupAPIApi
    from biotmed_settings_sdk.api.code_snippet_api_api import CodeSnippetAPIApi
    from biotmed_settings_sdk.api.entity_api_api import EntityAPIApi
    from biotmed_settings_sdk.api.export_import_configuration_api_api import ExportImportConfigurationAPIApi
    from biotmed_settings_sdk.api.health_check_api_api import HealthCheckAPIApi
    from biotmed_settings_sdk.api.interception_configuration_api_api import InterceptionConfigurationAPIApi
    from biotmed_settings_sdk.api.locale_api_api import LocaleAPIApi
    from biotmed_settings_sdk.api.plugin_v2_api_api import PluginV2APIApi
    from biotmed_settings_sdk.api.system_api_api import SystemAPIApi
    from biotmed_settings_sdk.api.template_api_api import TemplateAPIApi
    from biotmed_settings_sdk.api.translation_api_api import TranslationAPIApi
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            """# import apis into api package
from biotmed_settings_sdk.api.backup_api_api import BackupAPIApi
from biotmed_settings_sdk.api.code_snippet_api_api import CodeSnippetAPIApi
from biotmed_settings_sdk.api.entity_api_api import EntityAPIApi
from biotmed_settings_sdk.api.export_import_configuration_api_api import ExportImportConfigurationAPIApi
from biotmed_settings_sdk.api.health_check_api_api import HealthCheckAPIApi
from biotmed_settings_sdk.api.interception_configuration_api_api import InterceptionConfigurationAPIApi
from biotmed_settings_sdk.api.locale_api_api import LocaleAPIApi
from biotmed_settings_sdk.api.plugin_v2_api_api import PluginV2APIApi
from biotmed_settings_sdk.api.system_api_api import SystemAPIApi
from biotmed_settings_sdk.api.template_api_api import TemplateAPIApi
from biotmed_settings_sdk.api.translation_api_api import TranslationAPIApi

""",
            name=__name__,
            doc=__doc__,
        )
    )



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.partial_update_plugin_request import PartialUpdatePluginRequest

class TestPartialUpdatePluginRequest(unittest.TestCase):
    """PartialUpdatePluginRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PartialUpdatePluginRequest:
        """Test PartialUpdatePluginRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PartialUpdatePluginRequest`
        """
        model = PartialUpdatePluginRequest()
        if include_optional:
            return PartialUpdatePluginRequest(
                display_name = 'My Plugin 3',
                version = 1,
                runtime = 'python3.13',
                timeout = 60,
                handler = 'index.handler',
                memory_size = 128,
                environment_variables = {
                    'key' : None
                    },
                subscriptions = biotmed_settings_sdk.models.partial_update_subscription_dto.PartialUpdateSubscriptionDto(
                    interception_order = 1, 
                    interceptions = biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto.JsonNullableListInterceptionSubscriptionDto(
                        present = True, ), 
                    notifications = biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto.JsonNullableListInterceptionSubscriptionDto(
                        present = True, ), ),
                enabled_state = 'DISABLED',
                cron_schedule = '45',
                image_tag = '',
                analytics_db_access = True,
                cors = biotmed_settings_sdk.models.partial_plugin_cors_config.PartialPluginCorsConfig(
                    allow_origins = [*], 
                    allow_methods = [GET, POST], 
                    allow_headers = [authorization, content-type], 
                    expose_headers = [], ),
                ephemeral_storage = 512
            )
        else:
            return PartialUpdatePluginRequest(
                display_name = 'My Plugin 3',
                version = 1,
                runtime = 'python3.13',
                timeout = 60,
                handler = 'index.handler',
                memory_size = 128,
                environment_variables = {
                    'key' : None
                    },
                subscriptions = biotmed_settings_sdk.models.partial_update_subscription_dto.PartialUpdateSubscriptionDto(
                    interception_order = 1, 
                    interceptions = biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto.JsonNullableListInterceptionSubscriptionDto(
                        present = True, ), 
                    notifications = biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto.JsonNullableListInterceptionSubscriptionDto(
                        present = True, ), ),
                enabled_state = 'DISABLED',
                image_tag = '',
                analytics_db_access = True,
                ephemeral_storage = 512,
        )
        """

    def testPartialUpdatePluginRequest(self):
        """Test PartialUpdatePluginRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field
from typing import Optional
from typing_extensions import Annotated
from biotmed_settings_sdk.models.backup_request import BackupRequest
from biotmed_settings_sdk.models.backup_response import BackupResponse
from biotmed_settings_sdk.models.search_request_v2 import SearchRequestV2
from biotmed_settings_sdk.models.search_response_backup_response import SearchResponseBackupResponse
from biotmed_settings_sdk.models.search_response_restore_response import SearchResponseRestoreResponse

from biotmed_settings_sdk.api_client import ApiClient, RequestSerialized
from biotmed_settings_sdk.api_response import ApiResponse
from biotmed_settings_sdk.rest import RESTResponseType


class BackupAPIApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def backup(
        self,
        backup_request: BackupRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BackupResponse:
        """Backup

        Backup    This backup will be saved in an S3 bucket in AWS. The name parameter in the request will be the folder the backup is saved in the s3 bucket. The full path in which it will be saved is s3://<account-id>-backup/<backup-biot-version>/<name-from-request> E.g. for customer id 123456, biot version 2.3.11 and backup name backup1, the backup will be saved in the s3 path s3://123456-backup/2.3.11/backup1  Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |name|string|true|The name of the backup, it will also be the folder in which the backup is saved|Backup-01-02-2024| |description|string|false|The description of the backup|Backup after entity creation|   This API requires **SETTINGS_START_BACKUP** permission(s).  

        :param backup_request: (required)
        :type backup_request: BackupRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._backup_serialize(
            backup_request=backup_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '201': "BackupResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def backup_with_http_info(
        self,
        backup_request: BackupRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BackupResponse]:
        """Backup

        Backup    This backup will be saved in an S3 bucket in AWS. The name parameter in the request will be the folder the backup is saved in the s3 bucket. The full path in which it will be saved is s3://<account-id>-backup/<backup-biot-version>/<name-from-request> E.g. for customer id 123456, biot version 2.3.11 and backup name backup1, the backup will be saved in the s3 path s3://123456-backup/2.3.11/backup1  Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |name|string|true|The name of the backup, it will also be the folder in which the backup is saved|Backup-01-02-2024| |description|string|false|The description of the backup|Backup after entity creation|   This API requires **SETTINGS_START_BACKUP** permission(s).  

        :param backup_request: (required)
        :type backup_request: BackupRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._backup_serialize(
            backup_request=backup_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '201': "BackupResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def backup_without_preload_content(
        self,
        backup_request: BackupRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Backup

        Backup    This backup will be saved in an S3 bucket in AWS. The name parameter in the request will be the folder the backup is saved in the s3 bucket. The full path in which it will be saved is s3://<account-id>-backup/<backup-biot-version>/<name-from-request> E.g. for customer id 123456, biot version 2.3.11 and backup name backup1, the backup will be saved in the s3 path s3://123456-backup/2.3.11/backup1  Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |name|string|true|The name of the backup, it will also be the folder in which the backup is saved|Backup-01-02-2024| |description|string|false|The description of the backup|Backup after entity creation|   This API requires **SETTINGS_START_BACKUP** permission(s).  

        :param backup_request: (required)
        :type backup_request: BackupRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._backup_serialize(
            backup_request=backup_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '201': "BackupResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _backup_serialize(
        self,
        backup_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if backup_request is not None:
            _body_params = backup_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/system/backup',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def search_backup_executions(
        self,
        search_request: Annotated[Optional[SearchRequestV2], Field(description="Search request parameters: filter, sort and page")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SearchResponseBackupResponse:
        """Search Backup entities by filter

        Search Backup entities by filter  Returns list of Backup, the response can be filtered, sorted and supports pagination   **For more information and examples on creating search requests, click <a href=\"https://docs.biot-med.com/docs/using-biot-search-apis\" target=\"_blank\">here.</a>** ## Filter Each additionalProp can filter one field, inside additionalProp there are many optional conditions that can be used for filtering that field  By using the logical additionalProps $AND, $OR, $NOT, you can add complex nested logic filters. When sending these props, you must send only the nested filter field inside the filter value. This will allow you to group additional filters using logical AND/OR/NOT operators. When not sending a logic prop (including when not sending a nested logic prop), the props are bundled together using logical AND operators, this means that only the items that match all filter conditions for that field will be returned.  ***filter*** items possible values: [ *name*,*description*,*backupVersion*,*buildNumber*,*errorMessage*,*status*,*creationTime*,*lastModifiedTime* ]   ## Sort Results can be sorted by multiple fields, the order of the fields in the sort request governs the hierarchy of the sort  The first field is the primary sort, the second is used when two values of the first field are the same, and so forth  ***sort.order*** default value is DESC  ***sort.prop*** possible values:[ *name*,*description*,*backupVersion*,*buildNumber*,*errorMessage*,*status*,*creationTime*,*lastModifiedTime* ]  If sort was not specified, the result will be sorted by: creationTime DESC  ## Free text search When freeTextSearch is passed, the free text search will be performed on every field except those of type Date  If used together with filters, freeTextSearch will be bundled to the filters with the logical AND operator, this means that only items that match all filters (and each filter's conditions) and the free text search will be returned  ## Page ***limit*** max number of results that will be returned for each page. If not specify, the default will be 100  ***page*** page number starting from 0. If not specify, the default will be 0  ## Build URL Encode the JSON object and use the encoded string as the searchRequest parameter:  https://&lt;URL&gt;?searchRequest=<ENCODED_JSON_STRING>  Query Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |searchRequest||false|Search request parameters: filter, sort and page||   This API requires **SETTINGS_SEARCH_BACKUPS** permission(s).  

        :param search_request: Search request parameters: filter, sort and page
        :type search_request: SearchRequestV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_backup_executions_serialize(
            search_request=search_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "SearchResponseBackupResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def search_backup_executions_with_http_info(
        self,
        search_request: Annotated[Optional[SearchRequestV2], Field(description="Search request parameters: filter, sort and page")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SearchResponseBackupResponse]:
        """Search Backup entities by filter

        Search Backup entities by filter  Returns list of Backup, the response can be filtered, sorted and supports pagination   **For more information and examples on creating search requests, click <a href=\"https://docs.biot-med.com/docs/using-biot-search-apis\" target=\"_blank\">here.</a>** ## Filter Each additionalProp can filter one field, inside additionalProp there are many optional conditions that can be used for filtering that field  By using the logical additionalProps $AND, $OR, $NOT, you can add complex nested logic filters. When sending these props, you must send only the nested filter field inside the filter value. This will allow you to group additional filters using logical AND/OR/NOT operators. When not sending a logic prop (including when not sending a nested logic prop), the props are bundled together using logical AND operators, this means that only the items that match all filter conditions for that field will be returned.  ***filter*** items possible values: [ *name*,*description*,*backupVersion*,*buildNumber*,*errorMessage*,*status*,*creationTime*,*lastModifiedTime* ]   ## Sort Results can be sorted by multiple fields, the order of the fields in the sort request governs the hierarchy of the sort  The first field is the primary sort, the second is used when two values of the first field are the same, and so forth  ***sort.order*** default value is DESC  ***sort.prop*** possible values:[ *name*,*description*,*backupVersion*,*buildNumber*,*errorMessage*,*status*,*creationTime*,*lastModifiedTime* ]  If sort was not specified, the result will be sorted by: creationTime DESC  ## Free text search When freeTextSearch is passed, the free text search will be performed on every field except those of type Date  If used together with filters, freeTextSearch will be bundled to the filters with the logical AND operator, this means that only items that match all filters (and each filter's conditions) and the free text search will be returned  ## Page ***limit*** max number of results that will be returned for each page. If not specify, the default will be 100  ***page*** page number starting from 0. If not specify, the default will be 0  ## Build URL Encode the JSON object and use the encoded string as the searchRequest parameter:  https://&lt;URL&gt;?searchRequest=<ENCODED_JSON_STRING>  Query Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |searchRequest||false|Search request parameters: filter, sort and page||   This API requires **SETTINGS_SEARCH_BACKUPS** permission(s).  

        :param search_request: Search request parameters: filter, sort and page
        :type search_request: SearchRequestV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_backup_executions_serialize(
            search_request=search_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "SearchResponseBackupResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def search_backup_executions_without_preload_content(
        self,
        search_request: Annotated[Optional[SearchRequestV2], Field(description="Search request parameters: filter, sort and page")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search Backup entities by filter

        Search Backup entities by filter  Returns list of Backup, the response can be filtered, sorted and supports pagination   **For more information and examples on creating search requests, click <a href=\"https://docs.biot-med.com/docs/using-biot-search-apis\" target=\"_blank\">here.</a>** ## Filter Each additionalProp can filter one field, inside additionalProp there are many optional conditions that can be used for filtering that field  By using the logical additionalProps $AND, $OR, $NOT, you can add complex nested logic filters. When sending these props, you must send only the nested filter field inside the filter value. This will allow you to group additional filters using logical AND/OR/NOT operators. When not sending a logic prop (including when not sending a nested logic prop), the props are bundled together using logical AND operators, this means that only the items that match all filter conditions for that field will be returned.  ***filter*** items possible values: [ *name*,*description*,*backupVersion*,*buildNumber*,*errorMessage*,*status*,*creationTime*,*lastModifiedTime* ]   ## Sort Results can be sorted by multiple fields, the order of the fields in the sort request governs the hierarchy of the sort  The first field is the primary sort, the second is used when two values of the first field are the same, and so forth  ***sort.order*** default value is DESC  ***sort.prop*** possible values:[ *name*,*description*,*backupVersion*,*buildNumber*,*errorMessage*,*status*,*creationTime*,*lastModifiedTime* ]  If sort was not specified, the result will be sorted by: creationTime DESC  ## Free text search When freeTextSearch is passed, the free text search will be performed on every field except those of type Date  If used together with filters, freeTextSearch will be bundled to the filters with the logical AND operator, this means that only items that match all filters (and each filter's conditions) and the free text search will be returned  ## Page ***limit*** max number of results that will be returned for each page. If not specify, the default will be 100  ***page*** page number starting from 0. If not specify, the default will be 0  ## Build URL Encode the JSON object and use the encoded string as the searchRequest parameter:  https://&lt;URL&gt;?searchRequest=<ENCODED_JSON_STRING>  Query Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |searchRequest||false|Search request parameters: filter, sort and page||   This API requires **SETTINGS_SEARCH_BACKUPS** permission(s).  

        :param search_request: Search request parameters: filter, sort and page
        :type search_request: SearchRequestV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_backup_executions_serialize(
            search_request=search_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "SearchResponseBackupResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _search_backup_executions_serialize(
        self,
        search_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if search_request is not None:
            
            _query_params.append(('searchRequest', search_request))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/system/backup/executions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def search_restore_executions(
        self,
        search_request: Annotated[Optional[SearchRequestV2], Field(description="Search request parameters: filter, sort and page")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SearchResponseRestoreResponse:
        """Search Restore entities by filter

        Search Restore entities by filter  Returns list of Restore, the response can be filtered, sorted and supports pagination   **For more information and examples on creating search requests, click <a href=\"https://docs.biot-med.com/docs/using-biot-search-apis\" target=\"_blank\">here.</a>** ## Filter Each additionalProp can filter one field, inside additionalProp there are many optional conditions that can be used for filtering that field  By using the logical additionalProps $AND, $OR, $NOT, you can add complex nested logic filters. When sending these props, you must send only the nested filter field inside the filter value. This will allow you to group additional filters using logical AND/OR/NOT operators. When not sending a logic prop (including when not sending a nested logic prop), the props are bundled together using logical AND operators, this means that only the items that match all filter conditions for that field will be returned.  ***filter*** items possible values: [ *name*,*backupVersion*,*buildNumber*,*errorMessage*,*status*,*creationTime*,*lastModifiedTime* ]   ## Sort Results can be sorted by multiple fields, the order of the fields in the sort request governs the hierarchy of the sort  The first field is the primary sort, the second is used when two values of the first field are the same, and so forth  ***sort.order*** default value is DESC  ***sort.prop*** possible values:[ *name*,*backupVersion*,*buildNumber*,*errorMessage*,*status*,*creationTime*,*lastModifiedTime* ]  If sort was not specified, the result will be sorted by: creationTime DESC  ## Free text search When freeTextSearch is passed, the free text search will be performed on every field except those of type Date  If used together with filters, freeTextSearch will be bundled to the filters with the logical AND operator, this means that only items that match all filters (and each filter's conditions) and the free text search will be returned  ## Page ***limit*** max number of results that will be returned for each page. If not specify, the default will be 100  ***page*** page number starting from 0. If not specify, the default will be 0  ## Build URL Encode the JSON object and use the encoded string as the searchRequest parameter:  https://&lt;URL&gt;?searchRequest=<ENCODED_JSON_STRING>  Query Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |searchRequest||false|Search request parameters: filter, sort and page||   This API requires **SETTINGS_SEARCH_RESTORES** permission(s).  

        :param search_request: Search request parameters: filter, sort and page
        :type search_request: SearchRequestV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_restore_executions_serialize(
            search_request=search_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "SearchResponseRestoreResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def search_restore_executions_with_http_info(
        self,
        search_request: Annotated[Optional[SearchRequestV2], Field(description="Search request parameters: filter, sort and page")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SearchResponseRestoreResponse]:
        """Search Restore entities by filter

        Search Restore entities by filter  Returns list of Restore, the response can be filtered, sorted and supports pagination   **For more information and examples on creating search requests, click <a href=\"https://docs.biot-med.com/docs/using-biot-search-apis\" target=\"_blank\">here.</a>** ## Filter Each additionalProp can filter one field, inside additionalProp there are many optional conditions that can be used for filtering that field  By using the logical additionalProps $AND, $OR, $NOT, you can add complex nested logic filters. When sending these props, you must send only the nested filter field inside the filter value. This will allow you to group additional filters using logical AND/OR/NOT operators. When not sending a logic prop (including when not sending a nested logic prop), the props are bundled together using logical AND operators, this means that only the items that match all filter conditions for that field will be returned.  ***filter*** items possible values: [ *name*,*backupVersion*,*buildNumber*,*errorMessage*,*status*,*creationTime*,*lastModifiedTime* ]   ## Sort Results can be sorted by multiple fields, the order of the fields in the sort request governs the hierarchy of the sort  The first field is the primary sort, the second is used when two values of the first field are the same, and so forth  ***sort.order*** default value is DESC  ***sort.prop*** possible values:[ *name*,*backupVersion*,*buildNumber*,*errorMessage*,*status*,*creationTime*,*lastModifiedTime* ]  If sort was not specified, the result will be sorted by: creationTime DESC  ## Free text search When freeTextSearch is passed, the free text search will be performed on every field except those of type Date  If used together with filters, freeTextSearch will be bundled to the filters with the logical AND operator, this means that only items that match all filters (and each filter's conditions) and the free text search will be returned  ## Page ***limit*** max number of results that will be returned for each page. If not specify, the default will be 100  ***page*** page number starting from 0. If not specify, the default will be 0  ## Build URL Encode the JSON object and use the encoded string as the searchRequest parameter:  https://&lt;URL&gt;?searchRequest=<ENCODED_JSON_STRING>  Query Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |searchRequest||false|Search request parameters: filter, sort and page||   This API requires **SETTINGS_SEARCH_RESTORES** permission(s).  

        :param search_request: Search request parameters: filter, sort and page
        :type search_request: SearchRequestV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_restore_executions_serialize(
            search_request=search_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "SearchResponseRestoreResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def search_restore_executions_without_preload_content(
        self,
        search_request: Annotated[Optional[SearchRequestV2], Field(description="Search request parameters: filter, sort and page")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search Restore entities by filter

        Search Restore entities by filter  Returns list of Restore, the response can be filtered, sorted and supports pagination   **For more information and examples on creating search requests, click <a href=\"https://docs.biot-med.com/docs/using-biot-search-apis\" target=\"_blank\">here.</a>** ## Filter Each additionalProp can filter one field, inside additionalProp there are many optional conditions that can be used for filtering that field  By using the logical additionalProps $AND, $OR, $NOT, you can add complex nested logic filters. When sending these props, you must send only the nested filter field inside the filter value. This will allow you to group additional filters using logical AND/OR/NOT operators. When not sending a logic prop (including when not sending a nested logic prop), the props are bundled together using logical AND operators, this means that only the items that match all filter conditions for that field will be returned.  ***filter*** items possible values: [ *name*,*backupVersion*,*buildNumber*,*errorMessage*,*status*,*creationTime*,*lastModifiedTime* ]   ## Sort Results can be sorted by multiple fields, the order of the fields in the sort request governs the hierarchy of the sort  The first field is the primary sort, the second is used when two values of the first field are the same, and so forth  ***sort.order*** default value is DESC  ***sort.prop*** possible values:[ *name*,*backupVersion*,*buildNumber*,*errorMessage*,*status*,*creationTime*,*lastModifiedTime* ]  If sort was not specified, the result will be sorted by: creationTime DESC  ## Free text search When freeTextSearch is passed, the free text search will be performed on every field except those of type Date  If used together with filters, freeTextSearch will be bundled to the filters with the logical AND operator, this means that only items that match all filters (and each filter's conditions) and the free text search will be returned  ## Page ***limit*** max number of results that will be returned for each page. If not specify, the default will be 100  ***page*** page number starting from 0. If not specify, the default will be 0  ## Build URL Encode the JSON object and use the encoded string as the searchRequest parameter:  https://&lt;URL&gt;?searchRequest=<ENCODED_JSON_STRING>  Query Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |searchRequest||false|Search request parameters: filter, sort and page||   This API requires **SETTINGS_SEARCH_RESTORES** permission(s).  

        :param search_request: Search request parameters: filter, sort and page
        :type search_request: SearchRequestV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_restore_executions_serialize(
            search_request=search_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "SearchResponseRestoreResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _search_restore_executions_serialize(
        self,
        search_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if search_request is not None:
            
            _query_params.append(('searchRequest', search_request))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/system/restore/executions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.search_response_template_minimized_response import SearchResponseTemplateMinimizedResponse

class TestSearchResponseTemplateMinimizedResponse(unittest.TestCase):
    """SearchResponseTemplateMinimizedResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchResponseTemplateMinimizedResponse:
        """Test SearchResponseTemplateMinimizedResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchResponseTemplateMinimizedResponse`
        """
        model = SearchResponseTemplateMinimizedResponse()
        if include_optional:
            return SearchResponseTemplateMinimizedResponse(
                data = [
                    biotmed_settings_sdk.models.template_minimized_response.TemplateMinimizedResponse(
                        display_name = '0', 
                        name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0', 
                        description = '0', 
                        owner_organization_id = '', 
                        analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                            name = '', ), 
                        id = '', 
                        entity_type_name = '', 
                        removable = True, 
                        creation_time = '2007-12-20T10:15:30Z', 
                        last_modified_time = '2007-12-20T10:15:30Z', 
                        parent_template = biotmed_settings_sdk.models.parent_template_response.ParentTemplateResponse(
                            id = '', 
                            display_name = '', 
                            name = '', ), 
                        parent_template_id = '', )
                    ],
                metadata = biotmed_settings_sdk.models.metadata.Metadata(
                    sort = [
                        biotmed_settings_sdk.models.order.Order(
                            prop = '', 
                            order = 'ASC', )
                        ], 
                    filter = {
                        'key' : biotmed_settings_sdk.models.filter_v2.FilterV2(
                            in = [
                                ''
                                ], 
                            eq = null, 
                            lt = 20, 
                            lte = 25, 
                            gt = 25, 
                            gte = 25, 
                            like = 'John', 
                            from = '2007-12-20', 
                            to = '2007-12-20', 
                            is_null = True, 
                            is_not_null = True, 
                            not = null, 
                            not_in = [
                                ''
                                ], )
                        }, 
                    page = biotmed_settings_sdk.models.page_metadata.PageMetadata(
                        total_results = 145, 
                        limit = 100, ), 
                    free_text_search = 'cat dog', )
            )
        else:
            return SearchResponseTemplateMinimizedResponse(
                data = [
                    biotmed_settings_sdk.models.template_minimized_response.TemplateMinimizedResponse(
                        display_name = '0', 
                        name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0', 
                        description = '0', 
                        owner_organization_id = '', 
                        analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                            name = '', ), 
                        id = '', 
                        entity_type_name = '', 
                        removable = True, 
                        creation_time = '2007-12-20T10:15:30Z', 
                        last_modified_time = '2007-12-20T10:15:30Z', 
                        parent_template = biotmed_settings_sdk.models.parent_template_response.ParentTemplateResponse(
                            id = '', 
                            display_name = '', 
                            name = '', ), 
                        parent_template_id = '', )
                    ],
                metadata = biotmed_settings_sdk.models.metadata.Metadata(
                    sort = [
                        biotmed_settings_sdk.models.order.Order(
                            prop = '', 
                            order = 'ASC', )
                        ], 
                    filter = {
                        'key' : biotmed_settings_sdk.models.filter_v2.FilterV2(
                            in = [
                                ''
                                ], 
                            eq = null, 
                            lt = 20, 
                            lte = 25, 
                            gt = 25, 
                            gte = 25, 
                            like = 'John', 
                            from = '2007-12-20', 
                            to = '2007-12-20', 
                            is_null = True, 
                            is_not_null = True, 
                            not = null, 
                            not_in = [
                                ''
                                ], )
                        }, 
                    page = biotmed_settings_sdk.models.page_metadata.PageMetadata(
                        total_results = 145, 
                        limit = 100, ), 
                    free_text_search = 'cat dog', ),
        )
        """

    def testSearchResponseTemplateMinimizedResponse(self):
        """Test SearchResponseTemplateMinimizedResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.metadata import Metadata

class TestMetadata(unittest.TestCase):
    """Metadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Metadata:
        """Test Metadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Metadata`
        """
        model = Metadata()
        if include_optional:
            return Metadata(
                sort = [
                    biotmed_settings_sdk.models.order.Order(
                        prop = '', 
                        order = 'ASC', )
                    ],
                filter = {
                    'key' : biotmed_settings_sdk.models.filter_v2.FilterV2(
                        in = [
                            ''
                            ], 
                        eq = null, 
                        lt = 20, 
                        lte = 25, 
                        gt = 25, 
                        gte = 25, 
                        like = 'John', 
                        from = '2007-12-20', 
                        to = '2007-12-20', 
                        is_null = True, 
                        is_not_null = True, 
                        not = null, 
                        not_in = [
                            ''
                            ], 
                        filter = null, )
                    },
                page = biotmed_settings_sdk.models.page_metadata.PageMetadata(
                    total_results = 145, 
                    page = 3, 
                    limit = 100, ),
                free_text_search = 'cat dog'
            )
        else:
            return Metadata(
        )
        """

    def testMetadata(self):
        """Test Metadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.basic_attribute_data import BasicAttributeData

class TestBasicAttributeData(unittest.TestCase):
    """BasicAttributeData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BasicAttributeData:
        """Test BasicAttributeData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BasicAttributeData`
        """
        model = BasicAttributeData()
        if include_optional:
            return BasicAttributeData(
                id = '',
                name = '',
                display_name = '',
                base_path = '',
                reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                    uniquely = True, 
                    referenced_side_attribute_name = '', 
                    referenced_side_attribute_display_name = '', 
                    valid_templates_to_reference = [
                        ''
                        ], 
                    entity_type = '', ),
                template = biotmed_settings_sdk.models.basic_template_data.BasicTemplateData(
                    id = '', 
                    name = '', 
                    display_name = '', 
                    entity_type_name = '', )
            )
        else:
            return BasicAttributeData(
        )
        """

    def testBasicAttributeData(self):
        """Test BasicAttributeData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
